@@ -57,7 +57,7 @@ class ConnectionClass():
     if self.closed:
       raise MqClientExceptionClass("Trying to send message on closed STOMP connection")
     self._connectIfNeeded()
-    self.stompConnection.sendMessage(body=body, destination=internalDestination)
+    self.stompConnection.send(body=body, destination=internalDestination)
 
   def registerSubscription(self, internalDestination):
     self._connectIfNeeded()
@@ -69,4 +69,4 @@ class ConnectionClass():
 
   def close(self, wait):
     self.closed = True
-    self.stompConnection.close()
+    self.stompConnection.disconnect()
